@@ -13,7 +13,7 @@ def get_os_env(env_type='LC', env_path=None, env_file=None):
 
     env_value = {}
     if env_path is None:
-        env_path = str(Path.home())
+        env_path = '/home/work'
 
     if env_file is None:
         env_file = '.env'
