@@ -185,6 +185,10 @@ def _make_parameter_data(json_body):
     json_body['parameter'] = parameter
     return json_body
 
+def _make_feature_data(json_body):
+    json_body['feature'] = {}
+    json_body['feature']['importance'] = {}
+    return json_body
 
 def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
     # Convert json string to json dictionary, to pass to requests
@@ -192,6 +196,7 @@ def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
         json_body = json.loads(json_body)
         json_body = _make_metrics_data(json_body)
         json_body = _make_parameter_data(json_body)
+        json_body = _make_feature_data(json_body)
     if method == 'GET':
         response = http_request(
             host_creds=host_creds, endpoint=endpoint, method=method, params=json_body)
@@ -200,6 +205,7 @@ def call_endpoint(host_creds, endpoint, method, json_body, response_proto):
             host_creds=host_creds, endpoint=endpoint, method=method, json=json_body)
     response = verify_rest_response(response, endpoint)
     js_dict = json.loads(response.text)
+    print('backend Response result: ', js_dict)
     parse_dict(js_dict=js_dict, message=response_proto)
     return response_proto
 
